@@ -141,6 +141,7 @@ class Telegram:
 
     def stop(self) -> None:
         """Stops the client"""
+
         if self._stopped.is_set():
             return
 
@@ -317,6 +318,7 @@ class Telegram:
             'chat_id': chat_id,
             'message_id': message_id,
         }
+
         return self._send_data(data)
 
     def delete_messages(self, chat_id: int, message_ids: List[int], revoke: bool = True) -> AsyncResult:
@@ -328,6 +330,7 @@ class Telegram:
             message_ids
             revoke
         """
+
         return self._send_data(
             {
                 '@type': 'deleteMessages',
@@ -344,6 +347,7 @@ class Telegram:
         Args:
             supergroup_id
         """
+
         return self._send_data({'@type': 'getSupergroupFullInfo', 'supergroup_id': supergroup_id})
 
     def create_basic_group_chat(self, basic_group_id: int) -> AsyncResult:
@@ -353,6 +357,7 @@ class Telegram:
         Args:
             basic_group_id
         """
+
         return self._send_data({'@type': 'createBasicGroupChat', 'basic_group_id': basic_group_id})
 
     def get_web_page_instant_view(self, url: str, force_full: bool = False) -> AsyncResult:
@@ -424,6 +429,7 @@ class Telegram:
             logger.debug('async_result has not been found in by request_id=%s', request_id)
         else:
             done = async_result.parse_update(update)
+
             if done:
                 self._results.pop(request_id, None)
 
@@ -431,6 +437,7 @@ class Telegram:
 
     def _run_handlers(self, update: Dict[Any, Any]) -> None:
         update_type: str = update.get('@type', 'unknown')
+
         for handler in self._update_handlers[update_type]:
             self._workers_queue.put((handler, update), timeout=self._queue_put_timeout)
 
@@ -462,6 +469,7 @@ class Telegram:
 
         If `block`is True, waits for the result
         """
+
         if '@extra' not in data:
             data['@extra'] = {}
 
@@ -492,12 +500,13 @@ class Telegram:
         Blocks until one of the exit signals is received.
         When a signal is received, calls `stop`.
         """
+
         for sig in stop_signals:
             signal.signal(sig, self._stop_signal_handler)
 
         self._stopped.wait()
 
-    def _stop_signal_handler(self, signum: int, frame: FrameType) -> None:
+    def _stop_signal_handler(self, signum: int, frame: Optional[FrameType] = None) -> None:
         logger.info('Signal %s received!', signum)
         self.stop()
 
@@ -509,6 +518,7 @@ class Telegram:
 
     def _wait_authorization_result(self, result: AsyncResult) -> AuthorizationState:
         authorization_state = None
+
         if result:
             result.wait(raise_exc=True)
 
@@ -548,6 +558,7 @@ class Telegram:
            to the end user and then call register_user(first, last)
          - AuthorizationState.READY if the login process succeeded.
         """
+
         if self.proxy_server:
             self._send_add_proxy()
 
@@ -579,6 +590,7 @@ class Telegram:
                 return self.authorization_state
 
             result = actions[self.authorization_state]()
+
             if not isinstance(result, AuthorizationState):
                 self.authorization_state = self._wait_authorization_result(result)
             else:
@@ -616,6 +628,7 @@ class Telegram:
         logger.info('Sending encryption key')
 
         key = self._database_encryption_key
+
         if isinstance(key, str):
             key = key.encode()
 
@@ -628,6 +641,7 @@ class Telegram:
 
     def _send_phone_number_or_bot_token(self) -> AsyncResult:
         """Sends phone number or a bot_token"""
+
         if self.phone:
             return self._send_phone_number()
         elif self.bot_token:
@@ -655,6 +669,7 @@ class Telegram:
             'enable': True,
             'type': self.proxy_type,
         }
+
         return self._send_data(data, result_id='setProxy')
 
     def _send_bot_token(self) -> AsyncResult:
@@ -665,6 +680,7 @@ class Telegram:
 
     def _send_telegram_code(self, code: Optional[str] = None) -> AsyncResult:
         logger.info('Sending code')
+
         if code is None:
             code = input('Enter code:')
         data = {'@type': 'checkAuthenticationCode', 'code': str(code)}
@@ -691,6 +707,7 @@ class Telegram:
 
     def _send_password(self, password: Optional[str] = None) -> AsyncResult:
         logger.info('Sending password')
+
         if password is None:
             password = getpass.getpass('Password:')
         data = {'@type': 'checkAuthenticationPassword', 'password': password}
@@ -719,8 +736,10 @@ class Telegram:
 
     def _register_user(self, first: Optional[str] = None, last: Optional[str] = None) -> AsyncResult:
         logger.info('Registering user')
+
         if first is None:
             first = input('Enter first name: ')
+
         if last is None:
             last = input('Enter last name: ')
 
@@ -729,6 +748,7 @@ class Telegram:
             'first_name': first,
             'last_name': last,
         }
+
         return self._send_data(data, result_id='updateAuthorizationState')
 
     def register_user(self, first: str, last: str) -> AuthorizationState:
