@@ -1,17 +1,25 @@
 import json
 import logging
 import platform
+import ctypes.util
 from ctypes import CDLL, CFUNCTYPE, c_int, c_char_p, c_double, c_void_p, c_longlong
-from ctypes.util import find_library
 from typing import Any, Dict, Optional, Union
 
-import pkg_resources
-
 logger = logging.getLogger(__name__)
 
 
 def _get_tdjson_lib_path() -> str:
-    return find_library('tdjson')
+    system_library = ctypes.util.find_library("tdjson")
+
+    if system_library is not None:
+        return system_library
+
+    if platform.system().lower() == 'darwin':
+        lib_name = 'darwin/libtdjson.dylib'
+    else:
+        lib_name = 'linux/libtdjson.so'
+
+    return pkg_resources.resource_filename('telegram', f'lib/{lib_name}')
 
 
 class TDJson:
@@ -90,6 +98,7 @@ class TDJson:
         if result_str:
             result: Dict[Any, Any] = json.loads(result_str.decode('utf-8'))
             logger.debug('[me <==] Received %s', result)
+
             return result
 
         return None
@@ -100,6 +109,7 @@ class TDJson:
 
         if result_str:
             result: Dict[Any, Any] = json.loads(result_str.decode('utf-8'))
+
             return result
 
         return None
